@@ -243,6 +243,7 @@ class BlueprintInput():
         self.num_timepoints_found = deepcopy(num_timepoints_found)
         self.thr = deepcopy(thr)
         self.time_offset = deepcopy(time_offset)
+        self._time_resampled_to_trigger = None 
         if trigger_idx == 0:
             self.auto_trigger_selection()
         else:
@@ -340,10 +341,13 @@ class BlueprintInput():
             new_idx = slice(idx_dict['start'], idx_dict['stop'], idx_dict['step'])
             sliced_timeseries[n] = channel[new_idx]
 
-        return BlueprintInput(sliced_timeseries, self.freq, self.ch_name,
-                              self.units, self.trigger_idx,
-                              self.num_timepoints_found, self.thr,
-                              self.time_offset)
+        sliced_bp = BlueprintInput(sliced_timeseries, self.freq, self.ch_name,
+                                   self.units, self.trigger_idx,
+                                   self.num_timepoints_found, self.thr,
+                                   self.time_offset)
+
+        sliced_bp._time_resampled_to_trigger = self._time_resampled_to_trigger
+        return sliced_bp
 
     def __eq__(self, other):
         """
@@ -455,6 +459,7 @@ class BlueprintInput():
         Outcome:
         self.thr: float
             Threshold used by the function to detect trigger points.
+            If no threshold is provided, value is the mean of the trigger channel.
         self.num_timepoints_found: int
             Property of the `BlueprintInput` class.
             Contains the number of timepoints found
@@ -477,10 +482,16 @@ class BlueprintInput():
                         'of time to find the starting time.')
             time = np.linspace(time[0], time[-1], len(trigger))
 
-        # Check if thr was given, if not "guess" it.
+            self._time_resampled_to_trigger = time
+
         flag = 0
         if thr is None:
-            thr = np.mean(trigger) + 2 * np.std(trigger)
+            # If trigger channels are binary
+            # (i.e., "on" is a higher value and "off" is a lower value)
+            # and each "on" and "off" are each always approzimately the same value
+            # then any value above the mean is "on" and every value below the mean
+            # is "off".
+            thr = np.mean(trigger)
             flag = 1
         timepoints = trigger > thr
         num_timepoints_found = len([is_true for is_true, _ in groupby(timepoints,
